CRIEPI Audible Noise
========================

The following is the DC audible noise empirical formula which was developed by
the Central Research Institute of Electric Power Industry of Japan (CRIEPI).

DC
**

Surface gradient at 50dB:

.. image:: helpdocs/equations/criepi_dc_E_50.png

Surface gradient at 60dB:

.. image:: helpdocs/equations/criepi_dc_E_60.png

Sound pressure level:

.. image:: helpdocs/equations/criepi_dc_spl_50.png

Total sound pressure level from all phases:

.. image:: helpdocs/equations/spl_sum.png
